@@ -1,6 +1,6 @@
 package Pcore::API::Map::Field::Bool;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::API::Map::Field];
 
@@ -27,8 +27,6 @@ around ext_model_field => sub {
     return $field;
 };
 
-no Pcore;
-
 sub writer {
     my $self = shift;
     my $val  = shift;
