@@ -1,7 +1,7 @@
 package Pcore::API::PAUSE;
 
 use Pcore -class;
-use Pcore::API;
+use Pcore::API::Response;
 use Pcore::Util::Text qw[encode_utf8];
 
 has username => ( is => 'ro', isa => Str, required => 1 );
